import { source } from 'common-tags';
import { colorSetToVariants } from '../color-set/index.js';
const template = {
    name: 'swatch preview',
    render: async function* (colorSet) {
        yield* colorSetToVariants(colorSet).map(({ title, colors }) => {
            const gradientStops = [
                colors.shade7,
                colors.shade6,
                colors.shade5,
                colors.shade4,
                colors.shade3,
                colors.shade2,
                colors.shade1,
            ];
            const circles = [
                colors.accent0,
                colors.accent1,
                colors.accent2,
                colors.accent3,
                colors.accent4,
                colors.accent5,
                colors.accent6,
                colors.accent7,
            ];
            return {
                path: `${title.kebab}.svg`,
                content: source `
          <svg viewBox="0 0 480 160" version="1.1" xmlns="http://www.w3.org/2000/svg">
            <title>${title.human}</title>
            <defs>
              <linearGradient
                x1="0%"
                y1="50%"
                x2="100%"
                y2="50%"
                id="${title.kebab}"
              >
                ${gradientStops.map((stop, i) => source `
                    <stop
                      stop-color="${stop}"
                      offset="${(100 / (gradientStops.length - 1)) * i}%"
                    />
                  `)}
                {/each}
              </linearGradient>
            </defs>
            <rect
              x="0"
              y="0"
              width="100%"
              height="100%"
              fill="${colors.shade0}"
            />
            ${circles.map((circle, i) => source `
                <circle
                  fill="${circle}"
                  cx="${51 + 54 * i}"
                  cy="49"
                  r="21"
                />
              `)}
            <rect
              x="30"
              y="86"
              width="420"
              height="42"
              fill="url(#${title.kebab})"
            />
          </svg>
        `,
            };
        });
    },
    renderInstructions: () => '',
};
export default template;
//# sourceMappingURL=swatch.js.map